Struct fltk_webview::Webview [−][src]
pub struct Webview { /* fields omitted */ }Expand description
Webview wrapper
Implementations
Create a Webview from an embedded fltk window. Requires that the window is already shown
Navigate to a url
Evaluates arbitrary JavaScript code. Evaluation happens asynchronously
Posts a function to be executed on the main thread
Binds a native C callback so that it will appear under the given name as a global JavaScript function
Allows to return a value from the native binding.